@@ -17,7 +17,7 @@ def make_mesos_container_info(task_config: MesosTaskConfig) -> addict.Dict:
         volumes=thaw(task_config.volumes),
     )
     port_mappings = [addict.Dict(
-        host_port=task_config.ports[0].begin, container_port=8888)]
+        host_port=task_config.ports[0]['begin'], container_port=8888)]
     if container_info.type == 'DOCKER':
         container_info.docker = addict.Dict(
             image=task_config.image,
@@ -139,6 +139,8 @@ MESOS_STATUS_MAP = {
     addict.Dict(platform_type='gone_by_operator',
                 terminal=True, success=False),
     'TASK_UNKNOWN':
+    addict.Dict(platform_type='unknown', terminal=False),
+    'TASK_STUCK':
     addict.Dict(platform_type='unknown', terminal=False)
 }
 
